@@ -10,6 +10,7 @@ types: dict[str, str] = {
     "AWS::APS::ResourcePolicy": "da0d17341b025c5d",
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -69,7 +70,7 @@ types: dict[str, str] = {
     "AWS::AppMesh::VirtualService": "b6b6bd277d3b2302",
     "AWS::AppStream::AppBlock": "60a3a9b8f43b3525",
     "AWS::AppStream::AppBlockBuilder": "3087e48685697649",
-    "AWS::AppStream::Application": "4cf7a3e8ef43ac54",
+    "AWS::AppStream::Application": "357f39e2d6b0b31d",
     "AWS::AppStream::ApplicationEntitlementAssociation": "35e176c811a25063",
     "AWS::AppStream::ApplicationFleetAssociation": "93b71c4884fff935",
     "AWS::AppStream::DirectoryConfig": "d5a3c7fb900c1e1b",
@@ -89,7 +90,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -156,7 +157,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "4a5fa25f94471a0a",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
@@ -164,6 +165,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -187,9 +189,9 @@ types: dict[str, str] = {
     "AWS::Connect::AgentStatus": "e4d33392ae941342",
     "AWS::Connect::ApprovedOrigin": "9d9f12f666c7d568",
     "AWS::Connect::ContactFlow": "e7ed1215a325612c",
-    "AWS::Connect::ContactFlowModule": "e570c838d25e4a0e",
+    "AWS::Connect::ContactFlowModule": "8fa9fa9b46d0415e",
     "AWS::Connect::EvaluationForm": "f723bee2405abd32",
-    "AWS::Connect::HoursOfOperation": "a135dc27c162fc0e",
+    "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
     "AWS::Connect::IntegrationAssociation": "05d606eba9d7fcad",
@@ -225,18 +227,18 @@ types: dict[str, str] = {
     "AWS::DataBrew::Ruleset": "932632c822ce6169",
     "AWS::DataBrew::Schedule": "1995bc021a9e7e23",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationEFS": "dc695ceb626bd6aa",
-    "AWS::DataSync::LocationFSxLustre": "94324095d22e84c5",
-    "AWS::DataSync::LocationFSxONTAP": "fb2886550a94a821",
-    "AWS::DataSync::LocationFSxWindows": "7123c04a1159211f",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
+    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
+    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::Detective::Graph": "dbed0b7e7b29e1e6",
     "AWS::Detective::MemberInvitation": "86355f574dcf77f5",
     "AWS::Detective::OrganizationAdmin": "28db50ef7caf9609",
@@ -249,10 +251,10 @@ types: dict[str, str] = {
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
     "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
-    "AWS::EC2::CapacityReservation": "5b0dc1ffda2169f7",
+    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::ClientVpnAuthorizationRule": "09dec539b3c3f428",
-    "AWS::EC2::ClientVpnEndpoint": "9927a4c168876daf",
+    "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
@@ -272,7 +274,7 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "35088850e9d32a1c",
-    "AWS::EC2::Instance": "51763c48d327df98",
+    "AWS::EC2::Instance": "a922ff4a1cb10687",
     "AWS::EC2::InstanceConnectEndpoint": "aff65ea38d1b25dc",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
@@ -289,7 +291,7 @@ types: dict[str, str] = {
     "AWS::EC2::NetworkInsightsAccessScopeAnalysis": "d9d932b88ae8cef7",
     "AWS::EC2::NetworkInsightsAnalysis": "594bd95d5c037217",
     "AWS::EC2::NetworkInsightsPath": "25418106de92f812",
-    "AWS::EC2::NetworkInterface": "edc46868ad03781e",
+    "AWS::EC2::NetworkInterface": "1e436db5d46542c6",
     "AWS::EC2::NetworkInterfaceAttachment": "0d96c6d7269bdfb0",
     "AWS::EC2::NetworkInterfacePermission": "ff24405331f855c9",
     "AWS::EC2::PlacementGroup": "8dca9ce7eb8b50ac",
@@ -351,13 +353,13 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECR::SigningConfiguration": "2134ed8fb7551261",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
-    "AWS::ECS::Service": "75313434fba04f66",
+    "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
     "AWS::ECS::TaskSet": "93284b06523a426d",
     "AWS::EFS::AccessPoint": "2f62161de474e688",
@@ -373,7 +375,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::Studio": "0de4e6cff533d715",
     "AWS::EMR::StudioSessionMapping": "30c86bea7f3713ec",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
@@ -526,7 +528,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::IoTEvents::AlarmModel": "9663bd41a6ba5243",
     "AWS::IoTEvents::DetectorModel": "0527d423b1402c41",
@@ -546,6 +548,9 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
+    "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
+    "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
     "AWS::Kinesis::Stream": "e6126822cd48b2b0",
     "AWS::Kinesis::StreamConsumer": "7ce125c877a406e0",
@@ -567,14 +572,14 @@ types: dict[str, str] = {
     "AWS::LakeFormation::Tag": "e6965562c3f7e5bb",
     "AWS::LakeFormation::TagAssociation": "22d7f7ee98ca2b17",
     "AWS::Lambda::Alias": "88c6e095730810db",
-    "AWS::Lambda::CodeSigningConfig": "715ffad26c1d349b",
+    "AWS::Lambda::CodeSigningConfig": "078214085a4c3669",
     "AWS::Lambda::EventInvokeConfig": "eb90a4c91675fe09",
     "AWS::Lambda::EventSourceMapping": "8d7f59efe921b9e3",
     "AWS::Lambda::Function": "a0138839187c3dd7",
     "AWS::Lambda::LayerVersion": "f00fbc621c084236",
     "AWS::Lambda::LayerVersionPermission": "a46f7800bdd2c38c",
     "AWS::Lambda::Permission": "a43a5328bea4f6ad",
-    "AWS::Lambda::Version": "e59afa26437314bf",
+    "AWS::Lambda::Version": "e7fcd54deb138582",
     "AWS::LaunchWizard::Deployment": "2532c1afdd9c1f65",
     "AWS::Lex::Bot": "c8daa7de7e451807",
     "AWS::Lex::BotAlias": "2fedfd505da2ce12",
@@ -694,7 +699,7 @@ types: dict[str, str] = {
     "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
     "AWS::QuickSight::VPCConnection": "96804832324c84da",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
-    "AWS::RAM::ResourceShare": "301739e35a5f7f66",
+    "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
     "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
@@ -736,15 +741,15 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
-    "AWS::Route53Profiles::ProfileAssociation": "4ca94d598626a6c6",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
+    "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
     "AWS::Route53Resolver::FirewallRuleGroup": "c0eed6795a190c56",
     "AWS::Route53Resolver::FirewallRuleGroupAssociation": "d84c68a6ebbb5876",
     "AWS::Route53Resolver::ResolverConfig": "174be26547caaa42",
     "AWS::Route53Resolver::ResolverDNSSECConfig": "813fd8fe1e24c6e3",
-    "AWS::Route53Resolver::ResolverEndpoint": "8d7bd275c544d896",
+    "AWS::Route53Resolver::ResolverEndpoint": "d0ad42bf85f59279",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig": "78d814f813fdbcbf",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation": "41e93f940f8bce93",
     "AWS::Route53Resolver::ResolverRule": "a5bf3dc0f2b44d80",
@@ -753,8 +758,9 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
+    "AWS::S3::StorageLens": "bb038f16e3dd3fd9",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -769,6 +775,7 @@ types: dict[str, str] = {
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
     "AWS::SES::EmailIdentity": "be6211158f395729",
     "AWS::SES::Template": "20af669206370beb",
+    "AWS::SES::Tenant": "0c003f20faaf4446",
     "AWS::SES::VdmAttributes": "15df0379061c0489",
     "AWS::SMSVOICE::ConfigurationSet": "2bdda88e956e2a26",
     "AWS::SMSVOICE::OptOutList": "005f2438fbf815f8",
@@ -785,8 +792,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "67da7a687adc34fb",
-    "AWS::SSM::MaintenanceWindowTask": "bdd479736cab2d77",
+    "AWS::SSM::MaintenanceWindowTarget": "ab8754ee279cfae2",
+    "AWS::SSM::MaintenanceWindowTask": "4655ff7a49ab0f29",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -821,8 +828,8 @@ types: dict[str, str] = {
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
     "AWS::SecretsManager::ResourcePolicy": "cb5d330bf15d9d5a",
-    "AWS::SecretsManager::RotationSchedule": "1f88d2e8812cdf5d",
-    "AWS::SecretsManager::Secret": "4817d08ab5bef439",
+    "AWS::SecretsManager::RotationSchedule": "e02692fb717f1c08",
+    "AWS::SecretsManager::Secret": "9ee06ee7d6dbf7cf",
     "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
